@@ -1,10 +1,11 @@
 // This is a part of rust-encoding.
-// Copyright (c) 2013, Kang Seonghoon.
+// Copyright (c) 2013-2015, Kang Seonghoon.
 // See README.md and LICENSE.txt for details.
 
 //! 7-bit ASCII encoding.
 
 use std::{str, mem};
+use std::borrow::IntoCow;
 use types::*;
 
 /**
@@ -13,7 +14,7 @@ use types::*;
  * It is both a basis and a lowest common denominator of many other encodings
  * including UTF-8, which Rust internally assumes.
  */
-#[deriving(Clone, Copy)]
+#[derive(Clone, Copy)]
 pub struct ASCIIEncoding;
 
 impl Encoding for ASCIIEncoding {
@@ -23,7 +24,7 @@ impl Encoding for ASCIIEncoding {
 }
 
 /// An encoder for ASCII.
-#[deriving(Clone, Copy)]
+#[derive(Clone, Copy)]
 pub struct ASCIIEncoder;
 
 impl ASCIIEncoder {
@@ -58,7 +59,7 @@ impl RawEncoder for ASCIIEncoder {
 }
 
 /// A decoder for ASCII.
-#[deriving(Clone, Copy)]
+#[derive(Clone, Copy)]
 pub struct ASCIIDecoder;
 
 impl ASCIIDecoder {
